export declare enum MessageType {
    /**
     * worker => main
     */
    Inited = "inited",
    /**
     * main => worker
     */
    Request = "request",
    /**
     * worker => main
     */
    Response = "response",
    /**
     * publish async: main => worker
     */
    Invoke = "invoke",
    Broadcast = "broadcast"
}
export declare enum ListenerType {
    Inited = "inited",
    Request = "request",
    Subscribe = "Subscribe",
    WorkerChanged = "worker_changed",
    Error = "error"
}
export declare enum MessageCategory {
    IN = "in",
    OUT = "out"
}
export declare type Message<BODY = any> = {
    messageId: string;
    workerId: string;
    type: MessageType;
    error?: {
        name: string;
        message: string;
        stack: string;
    };
    body: BODY;
    messageOptions?: PublishOptions | BroadcastOptions;
};
export declare type EventCenterMessage = {
    messageCategory: MessageCategory;
    message: Message;
};
export interface EventBusOptions {
    initTimeout?: number;
    initTimeoutCheckInterval?: number;
    isWorker?: boolean;
}
export interface LocalEventBusOptions extends EventBusOptions {
    waitWorkerTimeout?: number;
    waitWorkerCheckInterval?: number;
}
export interface WaitCheckOptions {
    timeout?: number;
    timeoutCheckInterval?: number;
    ErrorClz?: new (...args: any[]) => Error;
}
export interface PublishOptions {
    relatedMessageId?: string;
    targetWorkerId?: string;
    topic?: string;
    timeout?: number;
    isChunk?: boolean;
}
export interface BroadcastOptions {
    /**
     * default false
     */
    includeSelfFromWorker?: boolean;
    /**
     * default false
     */
    includeMainFromWorker?: boolean;
    relatedMessageId?: string;
    relatedWorkerId?: string;
    topic?: string;
}
export interface SubscribeOptions {
    topic?: string;
    subscribeOnce?: boolean;
}
export declare type SubscribeTopicListener = (message: Message, responder?: IResponder) => void | Promise<void>;
export interface IEventBus<T> {
    addWorker(worker: T): any;
    start(err?: Error): Promise<void>;
    subscribe(callback: SubscribeTopicListener, options?: SubscribeOptions): void;
    subscribeOnce(callback: SubscribeTopicListener, options?: SubscribeOptions): void;
    publishAsync(data: unknown, publishOptions?: PublishOptions): Promise<any>;
    publishChunk(data: unknown, publishOptions?: PublishOptions): IDataCollector;
    publish(data: unknown, publishOptions?: PublishOptions): void;
    broadcast(data: unknown, options?: BroadcastOptions): void;
    isMain(): boolean;
    isWorker(): boolean;
    getWorkerId(worker: T): string;
    stop(): Promise<void>;
    onInited(listener: (message: Message) => void): any;
    onPublish(listener: (message: Message) => void): any;
    onSubscribe(listener: (message: Message) => void): any;
    onError(listener: (err: Error) => void): any;
}
export interface IDataCollector {
    onData(dataHandler: (data: unknown) => void): any;
    onEnd(endHandler: () => void): any;
    onError(errorHandler: (err: Error) => void): any;
}
export interface IResponder {
    end(data?: unknown): void;
    send(data: unknown): void;
    error(err: Error): void;
}
//# sourceMappingURL=interface.d.ts.map